@@ -16,7 +16,7 @@ require Exporter;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-01-10'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.345'; # VERSION
+our $VERSION = '0.346'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = (
@@ -375,7 +375,7 @@ sub _get_date_day_month_year {
     [200, "OK", [$date, $y, $m, $d]];
 }
 
-my %year_holidays;
+our %year_holidays;
 
 # decreed ?
 # source: https://id.wikipedia.org/wiki/1990
@@ -1628,7 +1628,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.345 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2022-01-10.
+This document describes version 0.346 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2022-01-10.
 
 =head1 SYNOPSIS
 
@@ -1711,7 +1711,10 @@ returns the number of working days in the current month:
 =head1 DESCRIPTION
 
 This module provides functions to list Indonesian holidays. There is a
-command-line script interface for this module: L<list-idn-holidays>.
+command-line script interface for this module: L<list-idn-holidays> and a few
+others distributed in L<App::IndonesianHolidayUtils> distribution.
+
+Calendar years supported: 1990-2022.
 
 Note: Note that sometimes the holiday (as set by law) falls at a different date
 than the actual religious commemoration date. When you use the C<detail> option,
